@@ -88,7 +88,7 @@ class Autorun(
             self._func = weakref.ref(func, self.unsubscribe)
         self._is_coroutine = (
             asyncio.coroutines._is_coroutine  # pyright: ignore [reportAttributeAccessIssue]  # noqa: SLF001
-            if asyncio.iscoroutinefunction(func) and not options.auto_await
+            if asyncio.iscoroutinefunction(func)
             else None
         )
         self._options = options
